#Setup variables
$ResourceGroupLocation = "local"
$ResourceGroupName = 'OdysseyRG'
$StorageAccountName = 'odysseystorage'
$StorageContainerName = $ResourceGroupName.ToLowerInvariant() + '-stageartifacts'
$DSCSourceFolder = '.\DSC'
$ArtifactStagingDirectory = "C:\Dev\OdysseyVM\Temp" 

#Connect to Azure Stack

#Create DSC configuration archive
if (Test-Path $DSCSourceFolder) {
    Add-Type -Assembly System.IO.Compression.FileSystem
    $ArchiveFile = Join-Path $ArtifactStagingDirectory "dsc.zip"
    Remove-Item -Path $ArchiveFile -ErrorAction SilentlyContinue
    [System.IO.Compression.ZipFile]::CreateFromDirectory($DSCSourceFolder, $ArchiveFile)
}

$StorageAccountContext = (Get-AzureRmStorageAccount -ResourceGroupName $ResourceGroupName 
-Name $StorageAccountName).Context

#Create storage container
New-AzureStorageContainer -Name $StorageContainerName -Context $StorageAccountContext 
-Permission Container

# Copy files from the local storage staging location to the storage account container
$ArtifactFilePaths = Get-ChildItem $ArtifactStagingDirectory -Recurse -File | ForEach-Object 
-Process {$_.FullName}
foreach ($SourcePath in $ArtifactFilePaths) {
    $BlobName = $SourcePath.Substring($ArtifactStagingDirectory.length + 1)
    Set-AzureStorageBlobContent -File $SourcePath -Blob $BlobName 
-Container $StorageContainerName -Context $StorageAccountContext -Force
}

# Generate the value for artifacts location SAS token (valid for 4 hours)
$ArtifactsLocationSasToken = New-AzureStorageContainerSASToken 
-Container $StorageContainerName -Context $StorageAccountContext 
-Permission r -ExpiryTime (Get-Date).AddHours(4)

#Set Artifacts URL
$ArtifactsLocation = $StorageAccountContext.BlobEndPoint + $StorageContainerName

"ArtifactsLocation: $ArtifactsLocation"
"ArtifactsLocationSasToken: $ArtifactsLocationSasToken"
